@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2025 the Eask authors.
+ * Copyright (C) 2022-2026 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 "use strict";
 
 exports.command = ['refresh'];
-exports.desc = 'Download package archives';
+exports.desc = 'Download descriptions of all configured package archives';
 
 exports.handler = async (argv) => {
   await UTIL.e_call(argv, 'core/refresh');
